OiRA

Help

1. Priprava
2. Vključevanje
3. Ocenjevanje
4. Poročilo
5. Status 92%

# Stanje Private Security, Grafton Street

## Splošne informacije

Uporabljeno orodje

  Private Security, Grafton Street

## Certification

### 92% Complete

92% Complete! You've earned a certificate for this tool.

With this certificate, you can apply for a reduction on your company's insurance rates. Learn more about the benefits…

View certificate

## Odgovorjena vprašanja na modul

Commercial manned guarding - Abby Road

  1 question answered without a risk

  3 answers indicated a risk and have at least one measure defined in the action plan

  2 answers indicated a risk without any measure defined in the action plan

  2 questions were postponed

  2 questions aren't answered yet

  - 1 Urejeno
  - 3
  - 2 Neurejeno
  - 2 Preloženo
  - 2 Neodgovorjeno

  #### Prednostna tveganja

  - Lorem ipsum
  - Dolor sit amet
  - Consectetuer vadifrimulus automobilis
Mobile partrolling/intervention after alarm

  7 Neodgovorjeno

  1

  1 Neurejeno

  1 Preloženo

  - 7 Neodgovorjeno
  - 1
  - 1 Neurejeno
  - 1 Preloženo

  #### High priority risks

  - Lorem ipsum
  - Dolor sit amet
  - Consectetuer vadifrimulus automobilis

Scroll to top
Back

## status-certificate.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More